@@ -1,6 +1,7 @@
 /*
     This file is part of the KDE project
     SPDX-FileCopyrightText: 2007 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2025 Harald Sitter <sitter@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -9,10 +10,14 @@
 
 #include "jobuidelegatefactory.h"
 #include "kiotesthelper.h"
+#include "worker_p.h"
+#include "workerbase.h"
+#include "workerfactory.h"
 #include <kio/copyjob.h>
 #include <kio/deletejob.h>
 #include <kio/jobuidelegateextension.h>
 #include <kio/simplejob.h>
+#include <kio/udsentry.h>
 #include <kprotocolinfo.h>
 
 #ifdef WITH_QTDBUS
@@ -22,9 +27,10 @@
 #include <KDirWatch>
 
 #include <QDebug>
-#include <QTemporaryFile>
 #include <QTest>
 
+using namespace Qt::StringLiterals;
+
 QTEST_MAIN(KDirListerTest)
 
 GlobalInits::GlobalInits()
@@ -45,7 +51,7 @@ void KDirListerTest::initTestCase()
     // To avoid failing on broken locally defined MIME types
     QStandardPaths::setTestModeEnabled(true);
 
-    m_tempDir.reset(new QTemporaryDir(tmpDirTemplate()));
+    m_tempDir.reset(new QTemporaryDir(homeTmpDir()));
 
     // No message dialogs
     KIO::setDefaultJobUiDelegateExtension(nullptr);
@@ -364,7 +370,7 @@ void KDirListerTest::testNewItemsInSymlink() // #213799
     const int origItemCount = m_items.count();
     QCOMPARE(fileCount(), origItemCount);
     const QString path = tempPath();
-    QTemporaryFile tempFile(tmpDirTemplate() + QStringLiteral("_normal_file"));
+    QTemporaryFile tempFile(homeTmpDir() + QStringLiteral("_normal_file"));
     QVERIFY(tempFile.open());
     const QString symPath = tempFile.fileName() + "_link";
     tempFile.close();
@@ -839,7 +845,7 @@ void KDirListerTest::testConcurrentListingAndStop()
     MyDirLister dirLister2;
 
     // Use a new tempdir for this test, so that we don't use the cache at all.
-    QTemporaryDir tempDir(tmpDirTemplate());
+    QTemporaryDir tempDir(homeTmpDir());
     const QString path = tempDir.path() + '/';
     createTestFile(path + "file_1");
     createTestFile(path + "file_2");
@@ -1031,7 +1037,7 @@ void KDirListerTest::testBug211472()
 {
     m_items.clear();
 
-    QTemporaryDir newDir(tmpDirTemplate());
+    QTemporaryDir newDir(homeTmpDir());
     const QString path = newDir.path() + "/newsubdir/";
     QDir().mkdir(path);
     MyDirLister dirLister;
@@ -1202,7 +1208,7 @@ void KDirListerTest::testListEmptyDirFromCache() // #278431
 {
     m_items.clear();
 
-    QTemporaryDir newDir(tmpDirTemplate());
+    QTemporaryDir newDir(homeTmpDir());
     const QUrl url = QUrl::fromLocalFile(newDir.path());
 
     // List and watch an empty dir
@@ -1238,7 +1244,7 @@ void KDirListerTest::testWatchingAfterCopyJob() // #331582
 {
     m_items.clear();
 
-    QTemporaryDir newDir(tmpDirTemplate());
+    QTemporaryDir newDir(homeTmpDir());
     const QString path = newDir.path() + '/';
 
     // List and watch an empty dir
@@ -1290,7 +1296,7 @@ void KDirListerTest::testRemoveWatchedDirectory()
 {
     m_items.clear();
 
-    QTemporaryDir newDir(tmpDirTemplate());
+    QTemporaryDir newDir(homeTmpDir());
     const QString path = newDir.path() + '/';
 
     // List and watch an empty dir
@@ -1331,7 +1337,7 @@ void KDirListerTest::testRemoveWatchedDirectory()
 
 void KDirListerTest::testDirPermissionChange()
 {
-    QTemporaryDir tempDir(tmpDirTemplate());
+    QTemporaryDir tempDir(homeTmpDir());
 
     const QString path = tempDir.path() + '/';
     const QString subdir = path + QLatin1String("subdir");
@@ -1476,7 +1482,7 @@ void KDirListerTest::testRenameDirectory() // #401552
 void KDirListerTest::testRequestMimeType()
 {
     // Use a new tempdir and lister instance for this test, so that we don't use any cache at all.
-    QTemporaryDir tempDir(tmpDirTemplate());
+    QTemporaryDir tempDir(homeTmpDir());
     QString path = tempDir.path() + QLatin1Char('/');
 
     createTestFile(path + "/file_1");
@@ -1538,7 +1544,7 @@ void KDirListerTest::testMimeFilter_data()
 void KDirListerTest::testMimeFilter()
 {
     // Use a new tempdir and lister instance for this test, so that we don't use any cache at all.
-    QTemporaryDir tempDir(tmpDirTemplate());
+    QTemporaryDir tempDir(homeTmpDir());
     QString path = tempDir.path() + '/';
 
     QFETCH(QStringList, files);
@@ -1588,7 +1594,7 @@ void KDirListerTest::testDeleteCurrentDir()
 
 void KDirListerTest::testForgetDir()
 {
-    QTemporaryDir tempDir(tmpDirTemplate());
+    QTemporaryDir tempDir(homeTmpDir());
     QString path = tempDir.path();
     createTestFile(path + "/file_1");
 
@@ -1658,7 +1664,7 @@ void KDirListerTest::waitUntilAfter(const QDateTime &ctime)
 // and stop watching a directory because a separate lister left a directory open in another lister
 void KDirListerTest::testBug386763()
 {
-    QTemporaryDir newDir(tmpDirTemplate());
+    QTemporaryDir newDir(homeTmpDir());
     const QString path = newDir.path() + "/newsubdir/";
     const QString otherpath = newDir.path() + "/othersubdir/";
 
@@ -1697,7 +1703,7 @@ void KDirListerTest::testBug386763()
 
 void KDirListerTest::testCacheEviction()
 {
-    QTemporaryDir newDir(tmpDirTemplate());
+    QTemporaryDir newDir(homeTmpDir());
 
     MyDirLister dirLister;
     dirLister.openUrl(QUrl::fromLocalFile(newDir.path()));
@@ -1721,9 +1727,10 @@ void KDirListerTest::testCacheEviction()
     QVERIFY(KDirWatch::self()->contains(newDir.path() + QString("dir_1")));
 }
 
-void KDirListerTest::testUnreadableParentDirectory() {
+void KDirListerTest::testUnreadableParentDirectory()
+{
 #ifdef WITH_QTDBUS
-    QTemporaryDir newDir(tmpDirTemplate());
+    QTemporaryDir newDir(homeTmpDir());
     MyDirLister dirLister;
 
     const QString hiddenPath = newDir.path() + QString("/hidden");
@@ -1773,7 +1780,7 @@ void KDirListerTest::testPathWithSquareBrackets()
 #if QT_VERSION == QT_VERSION_CHECK(6, 8, 3) || QT_VERSION == QT_VERSION_CHECK(6, 9, 0)
     QSKIP("This test is expected to fail on Qt 6.8.3 / 6.9.0");
 #endif
-    QTemporaryDir newDir(tmpDirTemplate());
+    QTemporaryDir newDir(homeTmpDir());
     QFile file(newDir.filePath("[test].txt"));
     QVERIFY(file.open(QIODevice::WriteOnly | QIODevice::Text));
     file.close();
@@ -1795,18 +1802,86 @@ void KDirListerTest::testPathWithSquareBrackets()
     QCOMPARE(m_refreshedItems.at(0).first.url(), QUrl::fromLocalFile(file.fileName()));
 }
 
-void KDirListerTest::testRemoteUrlEquals()
+void KDirListerTest::testSFTPRedirect()
 {
-    QUrl oldUrl(QStringLiteral("smb://foo.local"));
-    oldUrl.setPath(QStringLiteral(""));
-    QUrl newUrl(QStringLiteral("smb://foo.local"));
-    newUrl.setPath(QStringLiteral("/"));
-    m_dirLister.openUrl(oldUrl);
-    auto firstOpenedUrl = m_dirLister.url();
-    m_dirLister.openUrl(newUrl);
-    auto secondOpenedUrl = m_dirLister.url();
+    // This mock worker is needed to emulate very specific redirection case.
+    class Factory : public KIO::WorkerFactory
+    {
+    public:
+        using KIO::WorkerFactory::WorkerFactory;
+        std::unique_ptr<KIO::WorkerBase> createWorker(const QByteArray &pool, const QByteArray &app) override
+        {
+            class RedirectWorker : public KIO::WorkerBase
+            {
+            public:
+                RedirectWorker(const QByteArray &pool, const QByteArray &app)
+                    : WorkerBase(QByteArrayLiteral("kio-test"), pool, app)
+                {
+                }
 
-    QCOMPARE(firstOpenedUrl, secondOpenedUrl);
+                // This emulates the behavior sftp:// protocol does, when connecting to
+                // sftp://user@host -> it redirects to sftp://user@host/home/user
+                Q_REQUIRED_RESULT KIO::WorkerResult listDir(const QUrl &url) override
+                {
+                    if (url.toString() == u"kio-test://foo@bar"_s) {
+                        QUrl redir(url);
+                        redir.setPath(u"/home/foo"_s);
+                        redirection(redir);
+
+                        // It is important to return a pass() here, otherwise the DirItem will not be marked complete and
+                        // consequently isn't inserted into the cache.
+                        return KIO::WorkerResult::pass();
+                    }
+
+                    if (url.toString() == u"kio-test://foo@bar/home/foo"_s) {
+                        // Create fake entries
+                        auto fakeEntry = [](QString name, int size) {
+                            KIO::UDSEntry entry;
+                            entry.fastInsert(KIO::UDSEntry::UDS_SIZE, size);
+                            entry.fastInsert(KIO::UDSEntry::UDS_USER, QStringLiteral("user1"));
+                            entry.fastInsert(KIO::UDSEntry::UDS_GROUP, QStringLiteral("group1"));
+                            entry.fastInsert(KIO::UDSEntry::UDS_NAME, name);
+                            entry.fastInsert(KIO::UDSEntry::UDS_MODIFICATION_TIME, 123456);
+                            entry.fastInsert(KIO::UDSEntry::UDS_CREATION_TIME, 12345);
+                            entry.fastInsert(KIO::UDSEntry::UDS_DEVICE_ID, 2);
+                            entry.fastInsert(KIO::UDSEntry::UDS_INODE, 56);
+                            return entry;
+                        };
+
+                        listEntry(fakeEntry(QStringLiteral("filename1.json"), 10));
+                        listEntry(fakeEntry(QStringLiteral("filename2.txt"), 1000));
+                        listEntry(fakeEntry(QStringLiteral("."), 1));
+
+                        return KIO::WorkerResult::pass();
+                    }
+
+                    return KIO::WorkerResult::fail(KIO::ERR_UNSUPPORTED_ACTION, QStringLiteral("Unsupported URL: %1").arg(url.toString()));
+                }
+            };
+
+            return std::unique_ptr<KIO::WorkerBase>(new RedirectWorker(pool, app));
+        }
+    };
+    auto factory = std::make_shared<Factory>();
+    KIO::Worker::setTestWorkerFactory(factory);
+    QUrl testUrl(u"kio-test://foo@bar"_s);
+    MyDirLister dirLister;
+    // Mimic what dolphin does: upon redirection we open the redirected url. This is needless but exercises specific code paths.
+    connect(&dirLister, &KCoreDirLister::redirection, this, [&dirLister](const QUrl &oldUrl, const QUrl &newUrl) {
+        Q_UNUSED(oldUrl);
+        dirLister.openUrl(newUrl);
+    });
+    dirLister.openUrl(testUrl);
+    QVERIFY(dirLister.spyCompleted.wait(500));
+    // Make sure we have the items listed properly on the first time.
+    QVERIFY(dirLister.items().count() == 2);
+
+    // This should not crash!
+    dirLister.openUrl(testUrl);
+    QVERIFY(dirLister.spyCompleted.wait(500));
+    // This should not list any items: We have already done it in the previous iteration.
+    // If this lists items, the view (for example in Dolphin) will have the items duplicated.
+    QVERIFY(dirLister.items().count() == 0);
 }
 
 #include "moc_kdirlistertest.cpp"
