@@ -14,24 +14,27 @@
 class QUrl;
 class QEvent;
 
+class KUrlNavigator;
+
 namespace KDEPrivate
 {
-
-/**
- * @brief Base class for buttons of the URL navigator.
+/*!
+ * Base class for buttons of the URL navigator.
  *
  * Buttons of the URL navigator offer an active/inactive
  * state and custom display hints.
+ *
+ * \internal
  */
 class KUrlNavigatorButtonBase : public QPushButton
 {
     Q_OBJECT
 
 public:
-    explicit KUrlNavigatorButtonBase(QWidget *parent);
-    virtual ~KUrlNavigatorButtonBase();
+    explicit KUrlNavigatorButtonBase(KUrlNavigator *parent);
+    ~KUrlNavigatorButtonBase() override;
 
-    /**
+    /*!
      * When having several URL navigator instances, it is important
      * to provide a visual difference to indicate which URL navigator
      * is active (usecase: split view in Dolphin). The activation state
@@ -45,10 +48,12 @@ protected:
     enum DisplayHint {
         EnteredHint = 1,
         DraggedHint = 2,
-        PopupActiveHint = 4
+        PopupActiveHint = 4,
     };
 
-    enum { BorderWidth = 2 };
+    enum {
+        BorderWidth = 2
+    };
 
     void setDisplayHintEnabled(DisplayHint hint, bool enable);
     bool isDisplayHintEnabled(DisplayHint hint) const;
@@ -56,16 +61,16 @@ protected:
     void focusInEvent(QFocusEvent *event) override;
     void focusOutEvent(QFocusEvent *event) override;
 
-    void enterEvent(QEvent *event) override;
+    void enterEvent(QEnterEvent *event) override;
     void leaveEvent(QEvent *event) override;
 
     void drawHoverBackground(QPainter *painter);
 
-    /** Returns the foreground color by respecting the current display hint. */
+    /*! Returns the foreground color by respecting the current display hint. */
     QColor foregroundColor() const;
 
 private Q_SLOTS:
-    /** Invokes setActive(true). */
+    /*! Invokes setActive(true). */
     void activate();
 
 private:
