@@ -65,10 +65,10 @@ TrashImpl::TrashImpl()
     }
 }
 
-/**
+/*!
  * Test if a directory exists, create otherwise
- * @param _name full path of the directory
- * @return errorcode, or 0 if the dir was created or existed already
+ * \a _name full path of the directory
+ * Returns errorcode, or 0 if the dir was created or existed already
  * Warning, don't use return value like a bool
  */
 int TrashImpl::testDir(const QString &_name) const
@@ -856,6 +856,9 @@ void TrashImpl::fileRemoved()
 {
     if (isEmpty()) {
         deleteEmptyTrashInfrastructure();
+
+        // the file may have have changed by another trash:/ worker instance
+        m_config.reparseConfiguration();
         KConfigGroup group = m_config.group(QStringLiteral("Status"));
         group.writeEntry("Empty", true);
         m_config.sync();
@@ -1319,11 +1322,12 @@ bool TrashImpl::adaptTrashSize(const QString &origPath, int trashId)
     }
 
     // before we start to remove any files from the trash,
-    // check whether the new file will fit into the trash
-    // at all...
+    // check whether the new file can ever fit into the trash at all...
     const qint64 partitionSize = util.size();
+    const qint64 totalMaxSizeAllowed = qRound(partitionSize * percent / 100.0);
 
-    if ((util.usage(partitionSize + additionalSize)) >= percent) {
+    // Only reject if the new file itself is larger than the maximum allowed trash size
+    if (additionalSize > totalMaxSizeAllowed) {
         m_lastErrorCode = KIO::ERR_TRASH_FILE_TOO_LARGE;
         m_lastErrorMessage = KIO::buildErrorString(m_lastErrorCode, {});
         return false;
