@@ -5,12 +5,13 @@
     SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#include "searchproviderregistry.h"
 #include "searchprovider.h"
+#include "searchproviderregistry_p.h"
 
 #include <QDir>
 #include <QStandardPaths>
 
+using namespace KIO;
 SearchProviderRegistry::SearchProviderRegistry()
 {
     reload();
@@ -27,7 +28,7 @@ QStringList SearchProviderRegistry::directories() const
     if (!testDir.isEmpty()) {
         return {testDir};
     }
-    return QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("kservices5/searchproviders/"), QStandardPaths::LocateDirectory);
+    return QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("kf6/searchproviders/"), QStandardPaths::LocateDirectory);
 }
 
 void SearchProviderRegistry::reload()
